@@ -108,6 +108,27 @@ def get_number_of_lines(filename):
 
 #------------------------------------------------------------------------
 
+def get_number_of_columns(filename):
+    """
+    omit first 4 lines, take one line and tell
+    """
+    CMDL = ['head','-n','4', filename]
+    ps = sp.Popen( CMDL , stdout=sp.PIPE)
+    # print(" ".join(CMDL))
+    output = sp.check_output(('tail','-n','1'), stdin=ps.stdout)
+    ps.wait()
+    ncolumns=len(output.decode("utf8").strip().split())
+    if ncolumns==5:
+      print(f"D... {ncolumns} cols ... 2020+ version with pile-up info")
+    elif ncolumns==4:
+        print(f"D... {ncolumns} cols  ... 2018 version without pileup column")
+    else:
+        print("X... BAD NUMBER OF COLUMNS")
+        sys.exit()
+    return ncolumns
+
+#------------------------------------------------------------------------
+
 def filename_decomp(filename):
     """
     The ONLY procedure to get the start time from filename
@@ -125,22 +146,23 @@ def filename_decomp(filename):
 
     # 4 digits always
     if len(startd)==6:
+        print("D...  compensating 2 digit year to 4 digit year")
         startd="20"+startd
 
     print("D...  time start MARK=",startd+startt)
 
 
-    ok = False
+    #ok = False
     #try:
     start = dt.datetime.strptime(startd+startt,"%Y%m%d%H%M%S" )
-    ok = True
+    #ok = True
     print("D... succesfull start with 4 digit year")
+
     #except:
     #    print("x... year may not by 4 digits")
-
-    if not(ok):
-        print("X... trying 2 digits for year")
-        start = dt.datetime.strptime(startd+startt,"%y%m%d%H%M%S" )
+    #if not(ok):
+    #    print("X... trying 2 digits for year")
+    #    start = dt.datetime.strptime(startd+startt,"%y%m%d%H%M%S" )
 
     return start
 #------------------------------------------------------------------------
