@@ -243,14 +243,19 @@ def eva_cut_time(filename,  od=0, do=9999999 , chan=1):
     od_dt = dt.timedelta(seconds=od)
     do_dt = dt.timedelta(seconds=do)
     print(f"D... skip       {od} sec ... {od_dt}")
+
+
     startcut = start + od_dt
     stopcut = start + do_dt
     print(f"D... CUT  start {startcut}")
     print(f"D... CUT  stop  {stopcut}  (demanded or max)")
 
 
-    nlines = general.get_number_of_lines(filename)
-    print(f"i... reading the table of {nlines} lines ...")
+    nlines   = general.get_number_of_lines(filename)
+    ncolumns = general.get_number_of_columns(filename)
+    print(f"i... reading the table of {nlines} lines ... ({nlines/1e+6:.1f} milion lines)")
+    print(f"i... reading the table of {ncolumns} columns ... ", end="")
+
 
     # df = pd.read_table( filename, names=['time','E','x','ch','y'], sep = "\s+", comment="#")
     df = general.pd_read_table(filename)
@@ -273,7 +278,9 @@ def eva_cut_time(filename,  od=0, do=9999999 , chan=1):
     # print(f"D...  numpy array for ch {chan}  ________________________CUT___________")
     df1.reset_index(inplace=True, drop=True)
     print(df1)
-
+    if len(df1)==0:
+        print("D... no data for channel {chan}")
+        sys.exit(0)
 
     # dfzero = df1[ (df1.E==0) ]
     len_dfzero = general.pd_detect_zeroes(df1) # df1[ (df1.E==0) ]
